@@ -1,10 +1,6 @@
 """
 Core package
 
-contents:
-
-    client
-
 """
 
 from .client import Client
